@@ -6,8 +6,6 @@
 ;; Maintainer: Ef-Themes Development <~protesilaos/ef-themes@lists.sr.ht>
 ;; URL: https://git.sr.ht/~protesilaos/ef-themes
 ;; Mailing-List: https://lists.sr.ht/~protesilaos/ef-themes
-;; Version: 0.0.4
-;; Package-Requires: ((emacs "28.1"))
 ;; Keywords: faces, theme, accessibility
 
 ;; This file is part of GNU Emacs.
@@ -43,12 +41,15 @@
 
   (defconst ef-autumn-palette
     '(;; Basic tones
-      (bg-main  "#0f0e06")
-      (fg-main  "#cfbcba")
-      (bg-dim   "#1f1b19")
-      (fg-dim   "#887c8a")
-      (bg-alt   "#36322f")
-      (fg-alt   "#70a89f")
+      (bg-main     "#0f0e06")
+      (fg-main     "#cfbcba")
+      (bg-dim      "#1f1b19")
+      (fg-dim      "#887c8a")
+      (bg-alt      "#36322f")
+      (fg-alt      "#70a89f")
+
+      (bg-active   "#46423f")
+      (bg-inactive "#14130a")
 
       ;; Basic hues for foreground values
       (red             "#ef656a")
@@ -105,7 +106,6 @@
       (bg-hover-alt  "#6f345a")
       (bg-hl-line    "#302a3a")
       (bg-region     "#3f1020")
-      (bg-active     "#46423f")
       (bg-paren      "#7f2d40")
       (bg-err        "#361400") ; check with err
       (bg-info       "#152800") ; check with info
@@ -141,11 +141,11 @@
       (accent-2 cyan-cooler)
       (accent-3 magenta-cooler)
 
-      (mail-0 green-warmer)
-      (mail-1 red)
-      (mail-2 green-cooler)
-      (mail-3 yellow-warmer)
-      (mail-4 red-cooler)
+      (mail-0 yellow-warmer)
+      (mail-1 green-cooler)
+      (mail-2 red-warmer)
+      (mail-3 magenta)
+      (mail-4 green-warmer)
 
       (rainbow-0 yellow-warmer)
       (rainbow-1 green-warmer)
