@@ -6,8 +6,6 @@
 ;; Maintainer: Ef-Themes Development <~protesilaos/ef-themes@lists.sr.ht>
 ;; URL: https://git.sr.ht/~protesilaos/ef-themes
 ;; Mailing-List: https://lists.sr.ht/~protesilaos/ef-themes
-;; Version: 0.0.4
-;; Package-Requires: ((emacs "28.1"))
 ;; Keywords: faces, theme, accessibility
 
 ;; This file is part of GNU Emacs.
@@ -43,35 +41,38 @@
 
   (defconst ef-day-palette
     '(;; Basic tones
-      (bg-main  "#fff5ea")
-      (fg-main  "#584141")
-      (bg-dim   "#f5eddf")
-      (fg-dim   "#63728f")
-      (bg-alt   "#e9e0d8")
-      (fg-alt   "#8f5f4a")
+      (bg-main     "#fff5ea")
+      (fg-main     "#584141")
+      (bg-dim      "#f5eddf")
+      (fg-dim      "#63728f")
+      (bg-alt      "#e9e0d8")
+      (fg-alt      "#8f5f4a")
+
+      (bg-active   "#d9d0c8")
+      (bg-inactive "#f9f1e8")
 
       ;; Basic hues for foreground values
-      (red             "#c42d2f")
-      (red-warmer      "#d03003")
+      (red             "#ba2d2f")
+      (red-warmer      "#ce3f00")
       (red-cooler      "#cf2f4f")
       (red-faint       "#b05350")
-      (green           "#217a3c")
-      (green-warmer    "#4a7d00")
-      (green-cooler    "#007f68")
+      (green           "#2a7a0c")
+      (green-warmer    "#437000")
+      (green-cooler    "#0f7f5f")
       (green-faint     "#61756c")
       (yellow          "#a45a22")
-      (yellow-warmer   "#b6540f")
-      (yellow-cooler   "#ae5a30")
+      (yellow-warmer   "#b75515")
+      (yellow-cooler   "#aa4f30")
       (yellow-faint    "#a05f5a")
       (blue            "#375cc6")
       (blue-warmer     "#5f5fdf")
       (blue-cooler     "#265fbf")
       (blue-faint      "#4a659f")
-      (magenta         "#d5206f")
-      (magenta-warmer  "#cb26a0")
-      (magenta-cooler  "#9435b4")
+      (magenta         "#ca3e54")
+      (magenta-warmer  "#cb2f80")
+      (magenta-cooler  "#8448aa")
       (magenta-faint   "#a04450")
-      (cyan            "#1f6fbf")
+      (cyan            "#3f60af")
       (cyan-warmer     "#3f6faf")
       (cyan-cooler     "#0f7b8f")
       (cyan-faint      "#4f6f8f")
@@ -105,57 +106,56 @@
       (bg-hover-alt  "#febcaf")
       (bg-hl-line    "#f9e2b2")
       (bg-region     "#f0d2df")
-      (bg-active     "#d9d0c8")
       (bg-paren      "#8fcfdf")
       (bg-err        "#ffddee") ; check with err
       (bg-info       "#ddf5cc") ; check with info
 
       (border        "#ded0bb")
-      (cursor        "#df4f00")
+      (cursor        "#b00f00")
       (fg-intense    "#000000")
 
       ;; Mappings
       (err red-warmer)
       (warning yellow-warmer)
-      (info green)
+      (info green-warmer)
 
       (link red)
       (link-alt green-warmer)
-      (date green-warmer)
+      (date cyan-warmer)
       (name yellow)
       (keybind red-cooler)
 
-      (builtin red)
-      (comment magenta-faint)
-      (constant red-cooler)
-      (fnname green-warmer)
-      (keyword yellow-warmer)
-      (preprocessor magenta-warmer)
-      (docstring green-faint)
-      (string green)
-      (type blue-warmer)
-      (variable cyan)
+      (builtin red-cooler)
+      (comment green-faint)
+      (constant red-warmer)
+      (fnname magenta)
+      (keyword yellow)
+      (preprocessor cyan-warmer)
+      (docstring yellow-faint)
+      (string green-warmer)
+      (type green-cooler)
+      (variable magenta-cooler)
 
-      (accent-0 green)
-      (accent-1 red)
-      (accent-2 blue-warmer)
+      (accent-0 red)
+      (accent-1 green-cooler)
+      (accent-2 yellow)
       (accent-3 magenta-warmer)
 
-      (mail-0 yellow)
-      (mail-1 green-warmer)
-      (mail-2 red-cooler)
-      (mail-3 blue-warmer)
-      (mail-4 magenta)
+      (mail-0 red)
+      (mail-1 green)
+      (mail-2 yellow)
+      (mail-3 green-cooler)
+      (mail-4 yellow-cooler)
 
-      (rainbow-0 red-warmer)
-      (rainbow-1 yellow-cooler)
-      (rainbow-2 green-cooler)
+      (rainbow-0 yellow)
+      (rainbow-1 red)
+      (rainbow-2 green-warmer)
       (rainbow-3 magenta-warmer)
       (rainbow-4 cyan)
-      (rainbow-5 red-cooler)
-      (rainbow-6 green)
-      (rainbow-7 blue-warmer)
-      (rainbow-8 red))
+      (rainbow-5 yellow-cooler)
+      (rainbow-6 magenta-cooler)
+      (rainbow-7 red-cooler)
+      (rainbow-8 green-cooler))
     "The `ef-day' palette.")
 
   (ef-themes-theme ef-day ef-day-palette)
