@@ -6,8 +6,6 @@
 ;; Maintainer: Ef-Themes Development <~protesilaos/ef-themes@lists.sr.ht>
 ;; URL: https://git.sr.ht/~protesilaos/ef-themes
 ;; Mailing-List: https://lists.sr.ht/~protesilaos/ef-themes
-;; Version: 0.0.4
-;; Package-Requires: ((emacs "28.1"))
 ;; Keywords: faces, theme, accessibility
 
 ;; This file is part of GNU Emacs.
@@ -43,12 +41,15 @@
 
   (defconst ef-spring-palette
     '(;; Basic tones
-      (bg-main  "#f6fff9")
-      (fg-main  "#3f4946")
-      (bg-dim   "#e8f0f0")
-      (fg-dim   "#707586")
-      (bg-alt   "#e0e6e3")
-      (fg-alt   "#9d5e7a")
+      (bg-main     "#f6fff9")
+      (fg-main     "#3f4946")
+      (bg-dim      "#e8f0f0")
+      (fg-dim      "#707586")
+      (bg-alt      "#e0e6e3")
+      (fg-alt      "#9d5e7a")
+
+      (bg-active   "#d0d6d3")
+      (bg-inactive "#f0f8f4")
 
       ;; Basic hues for foreground values
       (red             "#c42d2f")
@@ -105,7 +106,6 @@
       (bg-hover-alt  "#feb5ff")
       (bg-hl-line    "#f9e0e5")
       (bg-region     "#d0e6ff")
-      (bg-active     "#d0d6d3")
       (bg-paren      "#8fddb0")
       (bg-err        "#ffe8e0") ; check with err
       (bg-info       "#ccf5dd") ; check with info
